FromOsStringError

Struct FromOsStringError 

pub struct FromOsStringError { /* private fields */ }
A possible error value while converting a OsString to a Utf8PathBuf.

Produced by the TryFrom<OsString> implementation for Utf8PathBuf.

Examples

use camino::{Utf8PathBuf, FromOsStringError};
use std::convert::{TryFrom, TryInto};
use std::ffi::OsStr;
use std::str::FromStr;
use std::ffi::OsString;
use std::os::unix::ffi::OsStrExt;

let unicode_string = OsString::from_str("/valid/unicode").unwrap();
let utf8_path_buf: Utf8PathBuf = unicode_string.try_into()
    .expect("valid Unicode path succeeded");

// Paths on Unix can be non-UTF-8.
let non_unicode_string = OsStr::from_bytes(b"\xFF\xFF\xFF").to_owned();
let err: FromOsStringError = Utf8PathBuf::try_from(non_unicode_string.clone())
    .expect_err("non-Unicode path failed");
assert_eq!(err.as_os_str(), &non_unicode_string);
assert_eq!(err.into_os_string(), non_unicode_string);

Implementations

Source

impl FromOsStringError

pub fn as_os_str(&self) -> &OsStr

Returns the OsStr slice that was attempted to be converted to Utf8PathBuf.

pub fn into_os_string(self) -> OsString

Returns the OsString that was attempted to be converted to Utf8PathBuf.

pub fn from_os_str_error(&self) -> FromOsStrError

Fetches a FromOsStrError for more about the conversion failure.

At the moment this struct does not contain any additional information, but is provided for completeness.

pub fn into_io_error(self) -> Error

Converts self into a std::io::Error with kind InvalidData.

Many users of FromOsStringError will want to convert it into an io::Error. This is a convenience method to do that.